
#include "config.h"

#include "kvlc.moc"

KVlc::KVlc() : KTMainWindow()
{
    btnHello = new QPushButton("Sarass", this);
    btnHello->setGeometry(45,30,50,25);
    btnHello->show();
    connect(btnHello, SIGNAL(clicked()), this, SLOT(slotHello()));

    btnExit = new QPushButton("Exit", this);
    btnExit->setGeometry(105,30,50,25);
    btnExit->show();
    connect(btnExit, SIGNAL(clicked()), this, SLOT(slotExit()));

    file = new QPopupMenu();
    file->insertItem("&Exit", this, SLOT(slotExit()));

    menu = new KMenuBar(this);
    menu->insertItem("&File", file);

}

void KVlc::closeEvent(QCloseEvent *)
{
    kapp->quit();
}

void KVlc::slotExit()
{
    close();
}

